# Permission to Relicense under MPLv2 or any other OSI approved license chosen by the current PyZMQ BDFL

This is a statement by Thomas Kluyver
that grants permission to relicense its copyrights in the Python ZeroMQ bindings
(pyzmq) under the Mozilla Public License v2 (MPLv2) or any other
Open Source Initiative approved license chosen by the current PyZMQ
BDFL (Benevolent Dictator for Life).

A portion of the commits made by the GitHub handle "takluyver", with
commit author "Thomas Kluyver <takowl@gmail.com>", are copyright of Thomas Kluyver.
This document hereby grants the libzmq project team to relicense libzmq,
including all past, present and future contributions of the author listed above.

Thomas Kluyver
2017/07/18
